<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>ShapePolygonAFCP</name>
    <message>
        <location filename="../ShapePolygonAFCP.js" line="+61"/>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Middle of Side</source>
        <translation>辺の中央</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location filename="../ShapePolygonAFCPInit.js" line="+2"/>
        <source>Pol&amp;ygon (Center, Side)</source>
        <translation>多角形（中心、辺）</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw regular polygon from center and middle point of side</source>
        <translation>中心と辺の中心から正多角形を描く</translation>
    </message>
    <message>
        <location filename="../ShapePolygonAFCP.ui" line="+17"/>
        <source>Corners:</source>
        <translation>頂点:</translation>
    </message>
</context>
</TS>
